# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   Autoloader plugin for Google SketchUp
# Created by Diggory Blake on 24 April 2011
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

require 'sketchup.rb'

module Autoloader
	@files = Hash.new

	def Autoloader.update(firstTime)
		updatedFiles = []
		failedFiles = []

		$:.each { |path|
			Dir.foreach(path) { |filename|
				if /\.rbs?$/ =~ filename.downcase then
					absname = File.expand_path(filename, path)
					modifiedTime = File.mtime(absname)
					
					if firstTime then
						@files[absname] = modifiedTime
					else
						upToDate = (@files.has_key?(absname) and (@files[absname] == modifiedTime))
						 
						if (!upToDate) then
							if Sketchup::load(absname) then
								updatedFiles << filename
								@files[absname] = modifiedTime
							else
								failedFiles << filename
							end
						end
					end
				end
			}
		}
		
		if !firstTime then
			statustext = ""
			if updatedFiles.length > 0 then
				statustext += "Loaded: " + updatedFiles.join(", ") + "   "
			end
			if failedFiles.length > 0 then
				statustext += "Failed: " + failedFiles.join(", ") + "   "
			end
			if (updatedFiles.length == 0) and (failedFiles.length == 0) then
				statustext += "All " + @files.length.to_s + " scripts up to date."
			end
			Sketchup.status_text = statustext
		end
		
		return failedFiles.length == 0
	end

	# Add menu items
	if not file_loaded? "autoloader.rb" then
		update(true)
	
		toolbar = UI::Toolbar.new "Autoloader"
		cmd = UI::Command.new("Update Scripts") { update(false) }
		cmd.small_icon = "AUTOLOADER_Dir/ruby_small.png"
		cmd.large_icon = "AUTOLOADER_Dir/ruby.png"
		cmd.tooltip = "Update Scripts"
		cmd.status_bar_text = "Automatically reload scripts which have been modified since the last update."
		
		toolbar.add_item cmd
		toolbar.restore
	end
end
